signature library
Classes
- Point
- one point on canvas represented by offset and type
- Signature
- signature canvas. Controller is required, other parameters are optional. widget/canvas expands to maximum by default. this behaviour can be overridden using width and/or height parameters.
- SignatureController
- class for interaction with signature widget manages points representing signature on canvas provides signature manipulation functions (export, clear)
- SignatureState
- signature widget state
Enums
- PointType
- type of user display finger movement